@@ -1,34 +1,5 @@
-# $Id: ANSI.pm 8696 2007-01-24 23:12:38Z Tim $
-#
-# Copyright (c) 2002  Tim Bunce  Ireland
-#
-# Constant data describing ANSI CLI info types and return values for the
-# SQLGetInfo() method of ODBC.
-#
-# You may distribute under the terms of either the GNU General Public
-# License or the Artistic License, as specified in the Perl README file.
-use strict;
-
 package DBI::Const::GetInfo::ANSI;
 
-our (%InfoTypes,%ReturnTypes,%ReturnValues,);
-
-=head1 NAME
-
-DBI::Const::GetInfo::ANSI - ISO/IEC SQL/CLI Constants for GetInfo
-
-=head1 SYNOPSIS
-
-  The API for this module is private and subject to change.
-
-=head1 DESCRIPTION
-
-Information requested by GetInfo().
-
-See: A.1 C header file SQLCLI.H, Page 316, 317.
-
-The API for this module is private and subject to change.
-
 =head1 REFERENCES
 
   ISO/IEC FCD 9075-3:200x Information technology - Database Languages -
@@ -38,10 +9,15 @@ The API for this module is private and subject to change.
 
   Date: 2002-01-15
 
-=cut
+=head1 Constants
 
-my
-$VERSION = "2.008697";
+=head2 %InfoTypes
+
+Information requested by GetInfo().
+
+See: A.1 C header file SQLCLI.H, Page 316, 317.
+
+=cut
 
 %InfoTypes =
 (
